@@ -196,20 +196,21 @@ class DistutilsInfo(object):
         self.values = {}
         if source is not None:
             for line in line_iter(source):
-                line = line.strip()
-                if line != '' and line[0] != '#':
+                line = line.lstrip()
+                if not line:
+                    continue
+                if line[0] != '#':
                     break
-                line = line[1:].strip()
+                line = line[1:].lstrip()
                 if line[:10] == 'distutils:':
-                    line = line[10:]
-                    ix = line.index('=')
-                    key = str(line[:ix].strip())
-                    value = line[ix+1:].strip()
+                    key, _, value = [s.strip() for s in line[10:].partition('=')]
                     type = distutils_settings[key]
                     if type in (list, transitive_list):
                         value = parse_list(value)
                         if key == 'define_macros':
-                            value = [tuple(macro.split('=')) for macro in value]
+                            value = [tuple(macro.split('=', 1))
+                                     if '=' in macro else (macro, None)
+                                     for macro in value]
                     self.values[key] = value
         elif exn is not None:
             for key in distutils_settings:
@@ -535,7 +536,7 @@ class DependencyTree(object):
             if pxd_file is not None:
                 pxd_list.append(pxd_file)
             elif not self.quiet:
-                print("missing cimport in module '%s': %s" % (module, filename))
+                print("%s: cannot find cimported module '%s'" % (filename, module))
         return tuple(pxd_list)
 
     @cached_method
@@ -652,10 +653,12 @@ def create_extension_list(patterns, exclude=None, ctx=None, aliases=None, quiet=
 
     # workaround for setuptools
     if 'setuptools' in sys.modules:
-       Extension_setuptools = sys.modules['setuptools'].Extension
+        Extension_distutils = sys.modules['setuptools.extension']._Extension
+        Extension_setuptools = sys.modules['setuptools'].Extension
     else:
-         # dummy class, in case we do not have setuptools
-         class Extension_setuptools(Extension): pass
+        # dummy class, in case we do not have setuptools
+        Extension_distutils = Extension
+        class Extension_setuptools(Extension): pass
 
     for pattern in patterns:
         if isinstance(pattern, str):
@@ -665,7 +668,7 @@ def create_extension_list(patterns, exclude=None, ctx=None, aliases=None, quiet=
             base = None
             exn_type = Extension
             ext_language = language
-        elif isinstance(pattern, (Extension, Extension_setuptools)):
+        elif isinstance(pattern, (Extension_distutils, Extension_setuptools)):
             for filepattern in pattern.sources:
                 if os.path.splitext(filepattern)[1] in ('.py', '.pyx'):
                     break
@@ -739,7 +742,7 @@ def create_extension_list(patterns, exclude=None, ctx=None, aliases=None, quiet=
                         **kwds))
                 if extra_sources:
                     kwds['sources'] = extra_sources
-                module_metadata[module_name] = {'distutils': kwds}
+                module_metadata[module_name] = {'distutils': kwds, 'module_name': module_name}
                 m = module_list[-1]
                 seen.add(name)
     return module_list, module_metadata
